@@ -3,6 +3,7 @@ from .melipayamak import MeliPayamak
 from .smsdotir import SmsDotIr
 from .webonesms import WebOneSms
 from .mediana import Mediana
+from .ghasedaksms import GhasedakSms
 
 __all__ = [
     "Kavenegar",
@@ -10,4 +11,5 @@ __all__ = [
     "WebOneSms",
     "MeliPayamak",
     "Mediana",
+    "GhasedakSms",
 ]
